/*********** mexMva.h **********/
#ifndef __MEXMVA__H__
#define __MEXMVA__H__

#ifndef BOOL
#define   BOOL   unsigned short     /* boolean type */
#endif /* BOOL */
 
#ifndef TRUE
#define   TRUE    ((BOOL) 1)     /* boolean true */
#define   FALSE   ((BOOL) 0)     /* boolean false */
#endif /* TRUE */

/* structure containg the input values for the MVA */
typedef struct
{
	int	iR; 		/* number of classes */
	int	iK;		/* number of stations */
	int	*piN;		/* piN[c] population of class c, 0<=c<=iR */
	BOOL	*pbQueue;	/* pbQueue[k] == TRUE the station k is a queue */
				/* pbQueue[k] == FALSE the station k is a delay center */
				/* 0<=k<=iK */
      double  *pdD;     /* pdD[c + iR*k] is the service demand of class c to */
                        /* to station k, 0<=c<=iR, 0<=k<=iK */
} MVAIN;


/* structure containg the output values for the MVA */
typedef struct
{

	double	*pdX;	/* pdX[c] is the throughput of the class c          */
			/* 0<=c<=iR					    */

	double	*pdU;   /* pdU[c + iR*k] is the utilization of the station  */
                        /* ik for the class c, 0<=c<=iR, 0<=k<=iK           */

	double  *pdQ;   /* pdQ[c + iR*k] is the queue length of the station */
                        /* ik for the class c, 0<=c<=iR, 0<=k<=iK           */

	double	*pdR;   /* pdW[c + iR*k] is the response time of the station*/
                        /* ik for the class c, 0<=c<=iR, 0<=k<=iK           */

	double	*pdRC;  /* pdRC[c] is the total response time of the class */
                        /* c, 0<=c<=iR 				           */

} MVAOUT;

void MVAFreeIN();
void MVAInit();
void MVARelese();

void MVAAlgo();

#endif /* __MEXMVA__H__ */
